##  Required Attributes
For your initial application portfolio assessment, capture the following attributes on applications.
Required Attributes for Applications Attributes | When to Add | Detailed Information
---|---|---
  * Name
  * Description

| Capture these fields when adding applications to your workspace. | [Add Applications](https://help.sap.com/docs/leanix/ea/add-applications?locale=en-US&state=PRODUCTION&version=CLOUD#loiodff14d9e29994311a5971d4d20229c48__section_qtj_hfn_ghc)
  * Relations to business capabilities
  * Relations to organizations

| Create relations after adding applications, business capabilities, and organizations to your workspace. | [Add Relations](https://help.sap.com/docs/leanix/ea/add-relations?locale=en-US&state=PRODUCTION&version=CLOUD "Link applications to business capabilities and organizations to show how they’re connected.")
  * Functional fit
  * Technical fit
  * Business criticality
  * Lifecycle

| Collect these fields from application owners after onboarding them into SAP LeanIX. | [Onboard Fact Sheet Owners and Collect Data](https://help.sap.com/docs/leanix/ea/collect-data-from-fact-sheet-owners?locale=en-US&state=PRODUCTION&version=CLOUD "Onboard fact sheet owners into SAP LeanIX and collect additional information from them to enrich your inventory data.")


